Task: DecaNLP: The Natural Language Decathlon
==============================================
Description: A collection of 10 tasks (SQuAD, IWSLT, CNN/DM, MNLI, SST, QA‑SRL,QA‑ZRE, WOZ, WikiSQL and MWSC) designed to challenge a model with a range of different tasks. Note that we use IWSLT 2014 instead of 2016/2013test/2014test for train/dev/test as given in the DecaNLP paper. See paper https://arxiv.org/abs/1806.08730 for more information and github: https://github.com/salesforce/decaNLP for data sources

Tags: #decanlp, #All

